@@ -1,3 +1,4 @@
+/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /* nautilus-pathbar.h
  *
  * This library is free software; you can redistribute it and/or
@@ -46,11 +47,11 @@ struct _NautilusPathBarClass
 {
 	GtkContainerClass parent_class;
 
-  	void (* path_clicked)   (NautilusPathBar  *path_bar,
-				 GFile             *location);
-        void (* path_event)     (NautilusPathBar  *path_bar,
-                                 GdkEventButton   *event,
-                                 GFile            *location);
+	void     (* path_clicked)   (NautilusPathBar  *path_bar,
+				     GFile            *location);
+	gboolean (* path_event)     (NautilusPathBar  *path_bar,
+				     GdkEventButton   *event,
+				     GFile            *location);
 };
 
 GType    nautilus_path_bar_get_type (void) G_GNUC_CONST;
